@@ -117,8 +117,8 @@ class GitHubRepoSession(ProjectHolder):
             return None
         if r.status_code != 200:
             raise BadProjectError(
-                'Error while identifying full repository on GitHub for search query: {}'.format(
-                    repo
+                'Error while identifying full repository on GitHub for search query: {}. Status: {}'.format(
+                    repo, r.status_code
                 )
             )
         data = r.json()
@@ -149,7 +149,9 @@ class GitHubRepoSession(ProjectHolder):
         # lazy loaded dict cache of /releases response keyed by tag, only first page
         self.formal_releases_by_tag = None
         self.rate_limited_count = 0
-        self.api_token = os.getenv("GITHUB_API_TOKEN")
+        self.api_token = os.getenv("LASTVERSION_GITHUB_API_TOKEN")
+        if not self.api_token:
+            self.api_token = os.getenv("GITHUB_API_TOKEN")
         if not self.api_token:
             self.api_token = os.getenv("GITHUB_TOKEN")
         self.hostname = hostname
@@ -183,7 +185,7 @@ class GitHubRepoSession(ProjectHolder):
         return '{}/rate_limit'.format(self.api_base)
 
     def get(self, url, **kwargs):
-        """Send GET reqiest and account for GitHub rate limits and such."""
+        """Send GET request and account for GitHub rate limits and such."""
         r = super(GitHubRepoSession, self).get(url, **kwargs)
         log.info('Got HTTP status code {} from {}'.format(r.status_code, url))
         if r.status_code == 401:
@@ -508,7 +510,7 @@ class GitHubRepoSession(ProjectHolder):
 
     def get_latest(self, pre_ok=False, major=None):
         """
-        Get the latest release satisfying "prereleases are OK" or major/branch constraints
+        Get the latest release satisfying "pre-releases are OK" or major/branch constraints
         Strives to fetch formal API release if it exists, because it has useful information
         like assets.
         """
@@ -545,7 +547,7 @@ class GitHubRepoSession(ProjectHolder):
                 # grab formal release via APi to check for pre-release mark
                 formal_release = self.get_formal_release_for_tag(tag_name)
                 if formal_release:
-                    # use full release info
+                    # use the full release info
                     ret = self.set_matching_formal_release(ret, formal_release, version, pre_ok)
                 else:
                     if self.having_asset:
