@@ -31,7 +31,7 @@ class ProjectHolder(requests.Session):
     LAST_CHAR_FIX_REQUIRED_ON = []
 
     # web accessible project holders may have single well-known domain usable by everyone
-    # in case of GitHub, that is github.com, for Mercurial web gui - here isn't one, etc.
+    # in case of GitHub, that is GitHub.com, for Mercurial web gui - here isn't one, etc.
     DEFAULT_HOSTNAME = None
     SUBDOMAIN_INDICATOR = None
     KNOWN_REPO_URLS = {}
@@ -41,7 +41,7 @@ class ProjectHolder(requests.Session):
     # is only one instead of 2
     # or a "format" specifier for matching
     REPO_URL_PROJECT_COMPONENTS = 2
-    # if URI starts with project name, 0. Otherwise skip through this many URI dirs
+    # if URI starts with project name, 0. Otherwise, skip through this many URI dirs
     REPO_URL_PROJECT_OFFSET = 0
     RELEASE_URL_FORMAT = None
     SHORT_RELEASE_URL_FORMAT = None
@@ -76,6 +76,7 @@ class ProjectHolder(requests.Session):
         self.name = None
         # in some case we do not specify repo, but feed is discovered, no repo is given then
         self.feed_url = None
+        self.even = False
 
     def is_valid(self):
         """Check if project holder is valid instance."""
@@ -99,6 +100,13 @@ class ProjectHolder(requests.Session):
             log.info('Only considering tags without "{}"'.format(exclude))
         return self
 
+    def set_even(self, even):
+        """Set to return only releases with even numbering like 1.2.3."""
+        self.even = even
+        if even:
+            log.info('Only considering releases with even numbering')
+        return self
+
     def set_having_asset(self, having_asset):
         """Sets "having_asset" selector for this holder."""
         self.having_asset = having_asset
@@ -227,6 +235,8 @@ class ProjectHolder(requests.Session):
             log.info('{} is not under the desired major {}'.format(
                 version_s, major))
             res = False
+        if res and self.even and not res.even:
+            return False
         return res
 
     def _type(self):
